import { __rest, __assign } from 'tslib';
import React, { forwardRef, useRef } from 'react';
import mergeRefs from 'react-merge-refs';
import cn from 'classnames';
import { dom } from '@alfalab/core-components-shared/esm';
import { useFocus } from '@alfalab/hooks';
import { CheckmarkCompactMIcon } from '@alfalab/icons-glyph/CheckmarkCompactMIcon';

var styles = {"component":"checkbox__component_6uq0w","start":"checkbox__start_6uq0w","center":"checkbox__center_6uq0w","addons":"checkbox__addons_6uq0w","block":"checkbox__block_6uq0w","box":"checkbox__box_6uq0w","checkedIcon":"checkbox__checkedIcon_6uq0w","size-20":"checkbox__size-20_6uq0w","disabled":"checkbox__disabled_6uq0w","checked":"checkbox__checked_6uq0w","indeterminate":"checkbox__indeterminate_6uq0w","indeterminateLine":"checkbox__indeterminateLine_6uq0w","label":"checkbox__label_6uq0w","hint":"checkbox__hint_6uq0w","focused":"checkbox__focused_6uq0w","content":"checkbox__content_6uq0w","errorMessage":"checkbox__errorMessage_6uq0w"};
require('./index.css')

var SIZE_TO_CLASSNAME_MAP = {
    s: 'size-20',
    m: 'size-24',
    20: 'size-20',
    24: 'size-24',
};
var Checkbox = forwardRef(function (_a, ref) {
    var _b;
    var checked = _a.checked, label = _a.label, hint = _a.hint, _c = _a.size, size = _c === void 0 ? 20 : _c, boxClassName = _a.boxClassName, contentClassName = _a.contentClassName, _d = _a.align, align = _d === void 0 ? 'start' : _d, addons = _a.addons, block = _a.block, onChange = _a.onChange, className = _a.className, name = _a.name, disabled = _a.disabled, inactive = _a.inactive, dataTestId = _a.dataTestId, _e = _a.indeterminate, indeterminate = _e === void 0 ? false : _e, _f = _a.hiddenInput, hiddenInput = _f === void 0 ? false : _f, labelProps = _a.labelProps, error = _a.error, restProps = __rest(_a, ["checked", "label", "hint", "size", "boxClassName", "contentClassName", "align", "addons", "block", "onChange", "className", "name", "disabled", "inactive", "dataTestId", "indeterminate", "hiddenInput", "labelProps", "error"]);
    var labelRef = useRef(null);
    var focused = useFocus(labelRef, 'keyboard')[0];
    var handleChange = function (event) {
        if (onChange) {
            onChange(event, { checked: event.target.checked, name: name });
        }
    };
    var errorMessage = typeof error === 'boolean' ? '' : error;
    return (React.createElement("label", __assign({}, labelProps, { className: cn(styles.component, styles[SIZE_TO_CLASSNAME_MAP[size]], styles[align], className, labelProps === null || labelProps === void 0 ? void 0 : labelProps.className, (_b = {},
            _b[styles.disabled] = disabled || inactive,
            _b[styles.checked] = checked,
            _b[styles.indeterminate] = indeterminate,
            _b[styles.focused] = focused,
            _b[styles.block] = block,
            _b)), ref: mergeRefs([labelRef, ref, labelProps === null || labelProps === void 0 ? void 0 : labelProps.ref]) }),
        !hiddenInput && (React.createElement("input", __assign({ type: 'checkbox', onChange: handleChange, disabled: disabled || inactive, checked: checked, "data-test-id": dataTestId }, restProps))),
        React.createElement("span", { className: cn(styles.box, boxClassName) },
            checked && React.createElement(CheckmarkCompactMIcon, { className: styles.checkedIcon }),
            indeterminate && !checked && React.createElement("span", { className: styles.indeterminateLine })),
        (label || hint || errorMessage) && (React.createElement("span", { className: cn(styles.content, contentClassName) },
            label && React.createElement("span", { className: styles.label }, label),
            hint && !errorMessage && React.createElement("span", { className: styles.hint }, hint),
            errorMessage && (React.createElement("span", { className: styles.errorMessage, role: 'alert' }, errorMessage)))),
        addons && (
        // eslint-disable-next-line jsx-a11y/click-events-have-key-events,jsx-a11y/no-static-element-interactions
        React.createElement("span", { className: styles.addons, onClick: dom.preventDefault }, addons))));
});
/**
 * Для отображения в сторибуке
 */
Checkbox.defaultProps = {
    indeterminate: false,
};

export { Checkbox };
