import React, { forwardRef, useRef } from 'react';
import mergeRefs from 'react-merge-refs';
import cn from 'classnames';
import { dom } from '@alfalab/core-components-shared/modern';
import { useFocus } from '@alfalab/hooks';
import { CheckmarkCompactMIcon } from '@alfalab/icons-glyph/CheckmarkCompactMIcon';

const styles = {"component":"checkbox__component_6uq0w","start":"checkbox__start_6uq0w","center":"checkbox__center_6uq0w","addons":"checkbox__addons_6uq0w","block":"checkbox__block_6uq0w","box":"checkbox__box_6uq0w","checkedIcon":"checkbox__checkedIcon_6uq0w","size-20":"checkbox__size-20_6uq0w","disabled":"checkbox__disabled_6uq0w","checked":"checkbox__checked_6uq0w","indeterminate":"checkbox__indeterminate_6uq0w","indeterminateLine":"checkbox__indeterminateLine_6uq0w","label":"checkbox__label_6uq0w","hint":"checkbox__hint_6uq0w","focused":"checkbox__focused_6uq0w","content":"checkbox__content_6uq0w","errorMessage":"checkbox__errorMessage_6uq0w"};
require('./index.css')

const SIZE_TO_CLASSNAME_MAP = {
    s: 'size-20',
    m: 'size-24',
    20: 'size-20',
    24: 'size-24',
};
const Checkbox = forwardRef(({ checked, label, hint, size = 20, boxClassName, contentClassName, align = 'start', addons, block, onChange, className, name, disabled, inactive, dataTestId, indeterminate = false, hiddenInput = false, labelProps, error, ...restProps }, ref) => {
    const labelRef = useRef(null);
    const [focused] = useFocus(labelRef, 'keyboard');
    const handleChange = (event) => {
        if (onChange) {
            onChange(event, { checked: event.target.checked, name });
        }
    };
    const errorMessage = typeof error === 'boolean' ? '' : error;
    return (React.createElement("label", { ...labelProps, className: cn(styles.component, styles[SIZE_TO_CLASSNAME_MAP[size]], styles[align], className, labelProps?.className, {
            [styles.disabled]: disabled || inactive,
            [styles.checked]: checked,
            [styles.indeterminate]: indeterminate,
            [styles.focused]: focused,
            [styles.block]: block,
        }), ref: mergeRefs([labelRef, ref, labelProps?.ref]) },
        !hiddenInput && (React.createElement("input", { type: 'checkbox', onChange: handleChange, disabled: disabled || inactive, checked: checked, "data-test-id": dataTestId, ...restProps })),
        React.createElement("span", { className: cn(styles.box, boxClassName) },
            checked && React.createElement(CheckmarkCompactMIcon, { className: styles.checkedIcon }),
            indeterminate && !checked && React.createElement("span", { className: styles.indeterminateLine })),
        (label || hint || errorMessage) && (React.createElement("span", { className: cn(styles.content, contentClassName) },
            label && React.createElement("span", { className: styles.label }, label),
            hint && !errorMessage && React.createElement("span", { className: styles.hint }, hint),
            errorMessage && (React.createElement("span", { className: styles.errorMessage, role: 'alert' }, errorMessage)))),
        addons && (
        // eslint-disable-next-line jsx-a11y/click-events-have-key-events,jsx-a11y/no-static-element-interactions
        React.createElement("span", { className: styles.addons, onClick: dom.preventDefault }, addons))));
});
/**
 * Для отображения в сторибуке
 */
Checkbox.defaultProps = {
    indeterminate: false,
};

export { Checkbox };
